# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import finnhub
from finnhub.models.aggregate_indicators import AggregateIndicators  # noqa: E501
from finnhub.rest import ApiException

class TestAggregateIndicators(unittest.TestCase):
    """AggregateIndicators unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AggregateIndicators
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = finnhub.models.aggregate_indicators.AggregateIndicators()  # noqa: E501
        if include_optional :
            return AggregateIndicators(
                technical_analysis = finnhub.models.technical_analysis.TechnicalAnalysis(
                    count = finnhub.models.indicator.Indicator(
                        buy = 56, 
                        neutral = 56, 
                        sell = 56, ), 
                    signal = '0', ), 
                trend = finnhub.models.trend.Trend(
                    adx = 1.337, )
            )
        else :
            return AggregateIndicators(
        )

    def testAggregateIndicators(self):
        """Test AggregateIndicators"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import finnhub
from finnhub.models.earnings_calendar import EarningsCalendar  # noqa: E501
from finnhub.rest import ApiException

class TestEarningsCalendar(unittest.TestCase):
    """EarningsCalendar unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test EarningsCalendar
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = finnhub.models.earnings_calendar.EarningsCalendar()  # noqa: E501
        if include_optional :
            return EarningsCalendar(
                earnings_calendar = [
                    None
                    ]
            )
        else :
            return EarningsCalendar(
        )

    def testEarningsCalendar(self):
        """Test EarningsCalendar"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from finnhub.configuration import Configuration


class Covid19(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'state': 'str',
        'case': 'float',
        'death': 'float',
        'updated': 'datetime'
    }

    attribute_map = {
        'state': 'state',
        'case': 'case',
        'death': 'death',
        'updated': 'updated'
    }

    def __init__(self, state=None, case=None, death=None, updated=None, local_vars_configuration=None):  # noqa: E501
        """Covid19 - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._state = None
        self._case = None
        self._death = None
        self._updated = None
        self.discriminator = None

        if state is not None:
            self.state = state
        if case is not None:
            self.case = case
        if death is not None:
            self.death = death
        if updated is not None:
            self.updated = updated

    @property
    def state(self):
        """Gets the state of this Covid19.  # noqa: E501

        State.  # noqa: E501

        :return: The state of this Covid19.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Covid19.

        State.  # noqa: E501

        :param state: The state of this Covid19.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def case(self):
        """Gets the case of this Covid19.  # noqa: E501

        Number of confirmed cases.  # noqa: E501

        :return: The case of this Covid19.  # noqa: E501
        :rtype: float
        """
        return self._case

    @case.setter
    def case(self, case):
        """Sets the case of this Covid19.

        Number of confirmed cases.  # noqa: E501

        :param case: The case of this Covid19.  # noqa: E501
        :type: float
        """

        self._case = case

    @property
    def death(self):
        """Gets the death of this Covid19.  # noqa: E501

        Number of confirmed deaths.  # noqa: E501

        :return: The death of this Covid19.  # noqa: E501
        :rtype: float
        """
        return self._death

    @death.setter
    def death(self, death):
        """Sets the death of this Covid19.

        Number of confirmed deaths.  # noqa: E501

        :param death: The death of this Covid19.  # noqa: E501
        :type: float
        """

        self._death = death

    @property
    def updated(self):
        """Gets the updated of this Covid19.  # noqa: E501

        Updated time.  # noqa: E501

        :return: The updated of this Covid19.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this Covid19.

        Updated time.  # noqa: E501

        :param updated: The updated of this Covid19.  # noqa: E501
        :type: datetime
        """

        self._updated = updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Covid19):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Covid19):
            return True

        return self.to_dict() != other.to_dict()
